@@ -20,6 +20,7 @@ from .widgets import filetree
 
 
 def run():
+    """Start a default difftool session"""
     files = selection.selected_group()
     if not files:
         return
@@ -29,6 +30,7 @@ def run():
 
 
 def launch_with_head(filenames, staged, head):
+    """Launch difftool against the provided head"""
     if head == 'HEAD':
         left = None
     else:
@@ -36,16 +38,29 @@ def launch_with_head(filenames, staged, head):
     launch(left=left, staged=staged, paths=filenames)
 
 
-def launch(left=None, right=None, paths=None,
-           left_take_parent=False, staged=False):
-    """Launches 'git difftool' with given parameters"""
+def launch(left=None, right=None, paths=None, staged=False, dir_diff=False,
+           left_take_magic=False, left_take_parent=False):
+    """Launches 'git difftool' with given parameters
+
+    :param left: first argument to difftool
+    :param right: second argument to difftool_args
+    :param paths: paths to diff
+    :param staged: activate `git difftool --staged`
+    :param dir_diff: activate `git difftool --dir-diff`
+    :param left_take_magic: whether to append the magic ^! diff expression
+    :param left_take_parent: whether to append the first-parent ~ for diffing
+
+    """
 
     difftool_args = ['git', 'difftool', '--no-prompt']
     if staged:
         difftool_args.append('--cached')
+    if dir_diff:
+        difftool_args.append('--dir-diff')
 
     if left:
-        if left_take_parent:
+        if left_take_parent or left_take_magic:
+            suffix = left_take_magic and '^!' or '~'
             # Check root commit (no parents and thus cannot execute '~')
             model = main.model()
             git = model.git
@@ -56,12 +71,14 @@ def launch(left=None, right=None, paths=None,
 
             if len(out.split()) >= 2:
                 # Commit has a parent, so we can take its child as requested
-                left += '~'
+                left += suffix
             else:
                 # No parent, assume it's the root commit, so we have to diff
-                # against the empty tree.  The empty tree is a built-in
-                # git constant SHA1.  The empty tree is a built-in Git SHA1.
+                # against the empty tree.  Git's empty tree is a built-in
+                # constant object name.
                 left = '4b825dc642cb6eb9a060e54bf8d69288fbee4904'
+                if not right and left_take_magic:
+                    right = left
         difftool_args.append(left)
 
     if right:
@@ -75,6 +92,7 @@ def launch(left=None, right=None, paths=None,
 
 
 def diff_commits(parent, a, b):
+    """Show a dialog for diffing two commits"""
     dlg = FileDiffDialog(parent, a=a, b=b)
     dlg.show()
     dlg.raise_()
@@ -82,8 +100,14 @@ def diff_commits(parent, a, b):
 
 
 def diff_expression(parent, expr,
-                    create_widget=False, hide_expr=False):
-    dlg = FileDiffDialog(parent, expr=expr, hide_expr=hide_expr)
+                    create_widget=False,
+                    hide_expr=False,
+                    focus_tree=False):
+    """Show a diff dialog for diff expressions"""
+    dlg = FileDiffDialog(parent,
+                         expr=expr,
+                         hide_expr=hide_expr,
+                         focus_tree=focus_tree)
     if create_widget:
         return dlg
     dlg.show()
@@ -94,7 +118,9 @@ def diff_expression(parent, expr,
 class FileDiffDialog(QtWidgets.QDialog):
 
     def __init__(self, parent, a=None, b=None, expr=None, title=None,
-                 hide_expr=False):
+                 hide_expr=False, focus_tree=False):
+        """Show files with differences and launch difftool"""
+
         QtWidgets.QDialog.__init__(self, parent)
         self.setAttribute(Qt.WA_MacMetalStyle)
 
@@ -120,11 +146,16 @@ class FileDiffDialog(QtWidgets.QDialog):
         self.diff_button = qtutils.create_button(text=N_('Compare'),
                                                  icon=icons.diff(),
                                                  enabled=False)
+        self.diff_all_button = qtutils.create_button(text=N_('Compare All'),
+                                                     icon=icons.diff())
         self.close_button = qtutils.close_button()
 
         self.button_layout = qtutils.hbox(defs.no_margin, defs.spacing,
                                           qtutils.STRETCH,
-                                          self.diff_button, self.close_button)
+                                          self.diff_button,
+                                          self.diff_all_button,
+                                          defs.spacing,
+                                          self.close_button)
 
         self.main_layout = qtutils.vbox(defs.margin, defs.spacing,
                                         self.expr, self.tree,
@@ -142,18 +173,27 @@ class FileDiffDialog(QtWidgets.QDialog):
         self.expr.enter.connect(self.focus_tree)
 
         qtutils.connect_button(self.diff_button, self.diff)
+        qtutils.connect_button(self.diff_all_button,
+                               lambda: self.diff(dir_diff=True))
         qtutils.connect_button(self.close_button, self.close)
 
         qtutils.add_action(self, 'Focus Input', self.focus_input, hotkeys.FOCUS)
+        qtutils.add_action(self, 'Diff All', lambda: self.diff(dir_diff=True),
+                           hotkeys.CTRL_ENTER, hotkeys.CTRL_RETURN)
         qtutils.add_close_action(self)
 
         self.resize(720, 420)
         self.refresh()
 
+        if focus_tree:
+            self.focus_tree()
+
     def focus_tree(self):
+        """Focus the files tree"""
         self.tree.setFocus()
 
     def focus_input(self):
+        """Focus the expression input"""
         self.expr.setFocus()
 
     def text_changed(self, txt):
@@ -161,6 +201,7 @@ class FileDiffDialog(QtWidgets.QDialog):
         self.refresh()
 
     def refresh(self):
+        """Redo the diff when the expression changes"""
         if self.diff_expr is not None:
             self.diff_arg = utils.shell_split(self.diff_expr)
         elif self.b is None:
@@ -177,17 +218,19 @@ class FileDiffDialog(QtWidgets.QDialog):
         self.tree.set_filenames(filenames, select=True)
 
     def tree_selection_changed(self):
-        self.diff_button.setEnabled(self.tree.has_selection())
+        has_selection = self.tree.has_selection()
+        self.diff_button.setEnabled(has_selection)
+        self.diff_all_button.setEnabled(has_selection)
 
     def tree_double_clicked(self, item, column):
         path = self.tree.filename_from_item(item)
         left, right = self._left_right_args()
         launch(left=left, right=right, paths=[path])
 
-    def diff(self):
+    def diff(self, dir_diff=False):
         paths = self.tree.selected_filenames()
         left, right = self._left_right_args()
-        launch(left=left, right=right, paths=paths)
+        launch(left=left, right=right, paths=paths, dir_diff=dir_diff)
 
     def _left_right_args(self):
         if self.diff_arg:
