@@ -1,19 +1,17 @@
 from __future__ import division, absolute_import, unicode_literals
 
-from PyQt4 import QtGui
-from PyQt4.QtCore import Qt
-from PyQt4.QtCore import SIGNAL
+from qtpy import QtWidgets
+from qtpy.QtCore import Qt
 
-from cola import cmds
-from cola import gitcfg
-from cola import gitcmds
-from cola import icons
-from cola import qtutils
-from cola.i18n import N_
-from cola.models import main
-from cola.widgets import completion
-from cola.widgets import defs
-from cola.compat import ustr
+from ..i18n import N_
+from ..models import main
+from .. import cmds
+from .. import gitcfg
+from .. import gitcmds
+from .. import icons
+from .. import qtutils
+from . import completion
+from . import defs
 
 
 def local_merge():
@@ -40,11 +38,11 @@ def abort_merge():
         gitcmds.abort_merge()
 
 
-class MergeView(QtGui.QDialog):
+class MergeView(QtWidgets.QDialog):
     """Provides a dialog for merging branches."""
 
     def __init__(self, cfg, model, parent=None):
-        QtGui.QDialog.__init__(self, parent)
+        QtWidgets.QDialog.__init__(self, parent)
         self.cfg = cfg
         self.model = model
         if parent is not None:
@@ -52,8 +50,8 @@ class MergeView(QtGui.QDialog):
         self.setAttribute(Qt.WA_MacMetalStyle)
 
         # Widgets
-        self.title_label = QtGui.QLabel()
-        self.revision_label = QtGui.QLabel()
+        self.title_label = QtWidgets.QLabel()
+        self.revision_label = QtWidgets.QLabel()
         self.revision_label.setText(N_('Revision to Merge'))
 
         self.revision = completion.GitRefLineEdit()
@@ -65,13 +63,13 @@ class MergeView(QtGui.QDialog):
 
         self.radio_tag = qtutils.radio(text=N_('Tag'))
 
-        self.revisions = QtGui.QListWidget()
+        self.revisions = QtWidgets.QListWidget()
         self.revisions.setAlternatingRowColors(True)
 
         self.button_viz = qtutils.create_button(text=N_('Visualize'),
                                                 icon=icons.visualize())
 
-        tooltip = N_('Squash the merged commit(s) into a single commit')
+        tooltip = N_('Squash the merged commits into a single commit')
         self.checkbox_squash = qtutils.checkbox(text=N_('Squash'),
                                                 tooltip=tooltip)
 
@@ -118,11 +116,8 @@ class MergeView(QtGui.QDialog):
         self.setLayout(self.mainlayt)
 
         # Signal/slot connections
-        self.connect(self.revision, SIGNAL('textChanged(QString)'),
-                     self.update_title)
-
-        self.connect(self.revisions, SIGNAL('itemSelectionChanged()'),
-                     self.revision_selected)
+        self.revision.textChanged.connect(self.update_title)
+        self.revisions.itemSelectionChanged.connect(self.revision_selected)
 
         qtutils.connect_button(self.button_close, self.reject)
         qtutils.connect_button(self.checkbox_squash, self.toggle_squash)
@@ -144,7 +139,7 @@ class MergeView(QtGui.QDialog):
 
     def update_title(self, dummy_txt=None):
         branch = self.model.currentbranch
-        revision = ustr(self.revision.text())
+        revision = self.revision.text()
         if revision:
             txt = (N_('Merge "%(revision)s" into "%(branch)s"') %
                    dict(revision=revision, branch=branch))
@@ -195,7 +190,7 @@ class MergeView(QtGui.QDialog):
 
     def viz_revision(self):
         """Launch a gitk-like viewer on the selection revision"""
-        revision = ustr(self.revision.text())
+        revision = self.revision.text()
         if not revision:
             qtutils.information(N_('No Revision Specified'),
                                 N_('You must specify a revision to view.'))
@@ -204,7 +199,7 @@ class MergeView(QtGui.QDialog):
 
     def merge_revision(self):
         """Merge the selected revision/branch"""
-        revision = ustr(self.revision.text())
+        revision = self.revision.text()
         if not revision:
             qtutils.information(N_('No Revision Specified'),
                                 N_('You must specify a revision to merge.'))
